@@ -34,16 +34,16 @@
 #'
 #' @examples
 #' adat <- data.frame(id = c(1, 2, 3),
-#'                    x1 = c(7, 3, 8))
+#'                    x1 = c(7, 3, 8), stringsAsFactors = FALSE)
 #'
 #' bdat <- data.frame(id = c(1, 2),
-#'                    x2 = c(5, 1))
+#'                    x2 = c(5, 1), stringsAsFactors = FALSE)
 #'
 #' cdat <- data.frame(id = c(2, 3),
-#'                    y3 = c(7, 9))
+#'                    y3 = c(7, 9), stringsAsFactors = FALSE)
 #'
 #' ddat <- data.frame(id = 4,
-#'                    y4 = 6)
+#'                    y4 = 6, stringsAsFactors = FALSE)
 #'
 #' # Merge adat, bdat, cdat, and data by the variable id
 #' df.merge(adat, bdat, cdat, ddat, by = "id")
@@ -56,22 +56,22 @@
 #' # Error messages
 #'
 #' adat <- data.frame(id = c(1, 2, 3),
-#'                    x1 = c(7, 3, 8))
+#'                    x1 = c(7, 3, 8), stringsAsFactors = FALSE)
 #'
 #' bdat <- data.frame(code = c(1, 2, 3),
-#'                    x2 = c(5, 1, 3))
+#'                    x2 = c(5, 1, 3), stringsAsFactors = FALSE)
 #'
 #' cdat <- data.frame(id = factor(c(1, 2, 3)),
-#'                    x3 = c(5, 1, 3))
+#'                    x3 = c(5, 1, 3), stringsAsFactors = FALSE)
 #'
 #' ddat <- data.frame(id = c(1, 2, 2),
-#'                    x2 = c(5, 1, 3))
+#'                    x2 = c(5, 1, 3), stringsAsFactors = FALSE)
 #'
 #' edat <- data.frame(id = c(1, NA, 3),
-#'                    x2 = c(5, 1, 3))
+#'                    x2 = c(5, 1, 3), stringsAsFactors = FALSE)
 #'
 #' fdat <- data.frame(id = c(1, 2, 3),
-#'                    x1 = c(5, 1, 3))
+#'                    x1 = c(5, 1, 3), stringsAsFactors = FALSE)
 #'
 #' # Error: Data frames do not have the same matching variable specified in 'by'.
 #' df.merge(adat, bdat, by = "id")
@@ -94,7 +94,7 @@ df.merge <- function(..., by, all = TRUE, check = TRUE, output = TRUE) {
   # Data
 
   # List of data frames
-  df <- lapply(list(...), as.data.frame)
+  df <- lapply(list(...), as.data.frame, stringsAsFactors = FALSE)
 
   ####################################################################################
   # Input Check
@@ -121,7 +121,7 @@ df.merge <- function(..., by, all = TRUE, check = TRUE, output = TRUE) {
 
     #......
     # Same matching variable in each data frame
-    if (any(vapply(df, function(y) !by %in%  names(y), FUN.VALUE = logical(1)))) {
+    if (any(vapply(df, function(y) !by %in%  names(y), FUN.VALUE = logical(1L)))) {
 
       stop("Data frames do not have the same matching variable specified in 'by'.", call. = FALSE)
 
@@ -129,7 +129,7 @@ df.merge <- function(..., by, all = TRUE, check = TRUE, output = TRUE) {
 
     #......
     # Same class
-    if (length(unique(vapply(df, function(y) class(y[, by]), FUN.VALUE = character(1)))) != 1) {
+    if (length(unique(vapply(df, function(y) class(y[, by]), FUN.VALUE = character(1L)))) != 1L) {
 
       stop("Matching variable in the data frames do not all have the same class.", call. = FALSE)
 
@@ -137,7 +137,7 @@ df.merge <- function(..., by, all = TRUE, check = TRUE, output = TRUE) {
 
     #......
     # Duplicated values in the matching variable
-    if (any(vapply(df, function(y) anyDuplicated(na.omit(y[, by])), FUN.VALUE = 1) != 0)) {
+    if (any(vapply(df, function(y) anyDuplicated(na.omit(y[, by])), FUN.VALUE = 1L) != 0L)) {
 
       stop("There are duplicated values in the matching variable specified in 'by'.", call. = FALSE)
 
@@ -145,7 +145,7 @@ df.merge <- function(..., by, all = TRUE, check = TRUE, output = TRUE) {
 
     #......
     # Missing values in the matching variable
-    if (any(vapply(df, function(y) any(is.na(y[, by])), FUN.VALUE = logical(1)))) {
+    if (any(vapply(df, function(y) any(is.na(y[, by])), FUN.VALUE = logical(1L)))) {
 
       stop("There are missing values in the matching variable specified in 'by'.", call. = FALSE)
 
@@ -153,7 +153,7 @@ df.merge <- function(..., by, all = TRUE, check = TRUE, output = TRUE) {
 
     #......
     # Duplicated variable names across the data frames
-    if (anyDuplicated(unlist(lapply(df, names))[unlist(lapply(df, names)) != by]) != 0) {
+    if (anyDuplicated(unlist(lapply(df, names))[unlist(lapply(df, names)) != by]) != 0L) {
 
       stop("There are duplicated variable names across data frames.", call. = FALSE)
 
@@ -184,22 +184,22 @@ df.merge <- function(..., by, all = TRUE, check = TRUE, output = TRUE) {
   no.dfs <- length(df)
 
   # Name of data frames
-  df.names <- as.character(match.call())[2:(no.dfs + 1)]
+  df.names <- as.character(match.call())[2L:(no.dfs + 1L)]
 
   # Number of variables in each data frame
-  no.var <- vapply(df, ncol, FUN.VALUE = 1)
+  no.var <- vapply(df, ncol, FUN.VALUE = 1L)
 
   # Number of cases in each data frame
-  no.cases <- vapply(df, nrow, FUN.VALUE = 1)
+  no.cases <- vapply(df, nrow, FUN.VALUE = 1L)
 
   # Matching variable
   var.match <- lapply(df, function(y) y[, by])
 
   # Match data frames
-  match.cases <- Reduce(function(xx, yy) misty::df.rbind(xx, yy), x = lapply(var.match, function(xx) data.frame(matrix(xx, ncol = length(xx), dimnames = list(NULL, xx)))))
+  match.cases <- Reduce(function(xx, yy) misty::df.rbind(xx, yy), x = lapply(var.match, function(xx) data.frame(matrix(xx, ncol = length(xx), dimnames = list(NULL, xx)), stringsAsFactors = FALSE)))
 
   # Number of pattern
-  match.cases.table <- table(apply(ifelse(is.na(match.cases), 0, 1), 2, paste, collapse = " "))
+  match.cases.table <- table(apply(ifelse(is.na(match.cases), 0L, 1L), 2, paste, collapse = " "))
 
   match.cases.table <- match.cases.table[rev(order(as.numeric(gsub(" ", "", names(match.cases.table)))))]
 
@@ -219,20 +219,20 @@ df.merge <- function(..., by, all = TRUE, check = TRUE, output = TRUE) {
 
   if (isTRUE(output)) {
 
-    print.object <- rbind(c("No. of data frames", no.dfs, rep("", times = no.dfs - 1)),
-                          rep("", times = no.dfs + 1),
+    print.object <- rbind(c("No. of data frames", no.dfs, rep("", times = no.dfs - 1L)),
+                          rep("", times = no.dfs + 1L),
                           cbind(c("", "No. of variables", "No. of cases"), rbind(df.names, no.var, no.cases)))
 
-    print.object[, 1] <- paste(" ", print.object[, 1])
+    print.object[, 1L] <- paste(" ", print.object[, 1L])
 
     # Format
-    print.object[, 1] <- format(print.object[, 1], justify = "left")
+    print.object[, 1L] <- format(print.object[, 1L], justify = "left")
 
-    print.object[, -1] <- format(print.object[, -1], justify = "right")
+    print.object[, -1L] <- format(print.object[, -1], justify = "right")
 
-    match.info <- format(data.frame(rbind(c("n", df.names), match.info)), justify = "right")
+    match.info <- format(data.frame(rbind(c("n", df.names), match.info), stringsAsFactors = FALSE), justify = "right")
 
-    match.info[, 1] <- paste("  ", match.info[, 1])
+    match.info[, 1L] <- paste("  ", match.info[, 1L])
 
     #........................................
     # Print output
