@@ -42,7 +42,7 @@
 #'                   group = c(1, 1, 1, 1, 2, 2, 3, 3, 3),
 #'                   x1 = c(2, 3, 2, 2, 1, 2, 3, 4, 2),
 #'                   x2 = c(3, 2, 2, 1, 2, 1, 3, 2, 5),
-#'                   x3 = c(2, 1, 2, 2, 3, 3, 5, 2, 4))
+#'                   x3 = c(2, 1, 2, 2, 3, 3, 5, 2, 4), stringsAsFactors = FALSE)
 #'
 #' # ICC(1) for x1
 #' multilevel.icc(dat$x1, group = dat$group)
@@ -75,7 +75,7 @@ multilevel.icc <- function(x, group, type = 1, method = c("aov", "lme4", "nlme")
 
   #......
   # Vector, matrix or data frame for the argument 'x'?
-  if (!is.vector(x) && !is.matrix(x) && !is.data.frame(x)) {
+  if (!is.atomic(x) && !is.matrix(x) && !is.data.frame(x)) {
 
     stop("Please specify a numeric vector, matrix or data frame with numeric variables for the argument 'x'.",
          call. = FALSE)
@@ -124,7 +124,7 @@ multilevel.icc <- function(x, group, type = 1, method = c("aov", "lme4", "nlme")
 
     #......
     # Check input 'group'
-    if (length(unique(na.omit(group))) == 1) {
+    if (length(unique(na.omit(group))) == 1L) {
 
       stop("There is only one group represented in the grouping variable specified in 'group'.",
            call. = FALSE)
@@ -159,7 +159,7 @@ multilevel.icc <- function(x, group, type = 1, method = c("aov", "lme4", "nlme")
     # Variance within group
     if (is.null(dim(x))) {
 
-      if (all(tapply(unlist(x), group, function(y) length(na.omit(y))) <= 1)) {
+      if (all(tapply(unlist(x), group, function(y) length(na.omit(y))) <= 1L)) {
 
         stop("Varialbe specified in 'x' does not have any within-group variance.", call. = FALSE)
 
@@ -167,7 +167,7 @@ multilevel.icc <- function(x, group, type = 1, method = c("aov", "lme4", "nlme")
 
     } else {
 
-      if (any(apply(x, 2, function(y) all(tapply(y, group, function(z) length(na.omit(z))) <= 1)))) {
+      if (any(apply(x, 2, function(y) all(tapply(y, group, function(z) length(na.omit(z))) <= 1L)))) {
 
         stop("There are variables in 'x' without any within-group variance.", call. = FALSE)
 
@@ -177,11 +177,11 @@ multilevel.icc <- function(x, group, type = 1, method = c("aov", "lme4", "nlme")
 
     #......
     # Check input 'x': Zero variance?
-    x.check <- vapply(as.data.frame(x), function(y) length(na.omit(unique(y))) == 1, FUN.VALUE = logical(1))
+    x.check <- vapply(as.data.frame(x), function(y) length(na.omit(unique(y))) == 1L, FUN.VALUE = logical(1))
 
     if (any(x.check)) {
 
-      if (length(x.check) > 1) {
+      if (length(x.check) > 1L) {
 
         warning(paste0("Following variables in the matrix or data frame specified in 'x' have zero variance: ",
                        paste(names(which(x.check)), collapse = ", ")), call. = FALSE)
@@ -196,7 +196,7 @@ multilevel.icc <- function(x, group, type = 1, method = c("aov", "lme4", "nlme")
 
     #......
     # Check input 'type'
-    if (any(!type %in% c(1, 2))) {
+    if (any(!type %in% c(1L, 2L))) {
 
       stop("Please specify the numeric value 1 or 2 for the argument'type'.", call. = FALSE)
 
@@ -264,7 +264,7 @@ multilevel.icc <- function(x, group, type = 1, method = c("aov", "lme4", "nlme")
 
     #............
     # Variable with non-zero variance
-    if (var(x, na.rm = TRUE) != 0) {
+    if (var(x, na.rm = TRUE) != 0L) {
 
       # ICC using aov() function
       if (method == "aov") {
@@ -282,15 +282,15 @@ multilevel.icc <- function(x, group, type = 1, method = c("aov", "lme4", "nlme")
         MSQ.W <- unlist(mod.summary[[2]])["Mean Sq"]
 
         # ICC(1)
-        if (type == 1) {
+        if (type == 1L) {
 
           # Average group size
           group.size <- mean(tapply(x, group, function(y) sum(!is.na(y))))
 
           # Intraclass correlation coefficient, ICC(1)
-          object <- unname((MSQ.B - MSQ.W) / (MSQ.B + ((group.size - 1) * MSQ.W)))
+          object <- unname((MSQ.B - MSQ.W) / (MSQ.B + ((group.size - 1L) * MSQ.W)))
 
-          if (object < 0) { object <- 0 }
+          if (object < 0L) { object <- 0L }
 
         # ICC(2)
         } else {
@@ -298,7 +298,7 @@ multilevel.icc <- function(x, group, type = 1, method = c("aov", "lme4", "nlme")
           # Intraclass correlation coefficient, ICC(2)
           object <- unname((MSQ.B - MSQ.W) / MSQ.B)
 
-          if (object < 0) { object <- 0 }
+          if (object < 0L) { object <- 0L }
 
         }
 
