@@ -4,7 +4,7 @@
 #'
 #' @param x           \code{cohens.d} object.
 #' @param digits      an integer value indicating the number of decimal places to be used for
-#'                    displayingresults.
+#'                    displaying results.
 #' @param check       logical: if \code{TRUE}, argument specification is checked.
 #' @param ...         further arguments passed to or from other methods.
 #'
@@ -23,7 +23,7 @@
 #' dat.bs <- data.frame(group = c("cont", "cont", "cont", "treat",  "treat"),
 #'                      y1 = c(1, 3, 2, 5, 7),
 #'                      y2 = c(4, 3, 3, 6, 4),
-#'                      y3 = c(7, 5, 7, 3, 2))
+#'                      y3 = c(7, 5, 7, 3, 2), stringsAsFactors = FALSE)
 #'
 #' # Standardized mean difference divided by the weighted pooled
 #' # standard deviation without small sample correction factor
@@ -35,7 +35,7 @@
 #' #--------------------------------------
 #' # Within-subject design
 #' dat.ws <- data.frame(pre = c(1, 3, 2, 5, 7),
-#'                      post = c(2, 2, 1, 6, 8))
+#'                      post = c(2, 2, 1, 6, 8), stringsAsFactors = FALSE)
 #'
 #' # Standardized mean difference divided by the pooled
 #' # standard deviation while controlling for the correlation
@@ -54,7 +54,7 @@ print.cohens.d <- function(x, digits = x$args$digits, check = TRUE, ...) {
   if (isTRUE(check)) {
 
     # Check input 'digits'
-    if (digits %% 1 != 0 | digits < 0) {
+    if (digits %% 1L != 0L | digits < 0L) {
 
       stop("Specify a positive integer number for the argument 'digits'", call. = FALSE)
 
@@ -76,38 +76,38 @@ print.cohens.d <- function(x, digits = x$args$digits, check = TRUE, ...) {
   if (isFALSE(x$args$paired)) {
 
     print.object[, !names(print.object) %in% c("variable", "n1", "n2", "nNA1", "nNA2")] <- vapply(print.object[,  !names(print.object) %in% c("variable", "n1", "n2", "nNA1", "nNA2")], function(y) ifelse(!is.na(y), formatC(y, format = "f", digits = digits), NA), FUN.VALUE = character(nrow(x$result)))
-    print.object[, names(print.object) %in% c("n1", "n2", "nNA1", "nNA2")] <- vapply(print.object[,  names(print.object) %in% c("n1", "n2", "nNA1", "nNA2")], function(y) formatC(y, format = "f", digits = 0), FUN.VALUE = character(nrow(x$result)))
+    print.object[, names(print.object) %in% c("n1", "n2", "nNA1", "nNA2")] <- vapply(print.object[,  names(print.object) %in% c("n1", "n2", "nNA1", "nNA2")], function(y) formatC(y, format = "f", digits = 0L), FUN.VALUE = character(nrow(x$result)))
 
     print.object <- rbind(c("Variable", "n1", "nNA1", "M1", "SD1",  "n2", "nNA2", "M2", "SD2", "M.Diff", "SD", "Estimate", "SE", "Low", "Upp"),
                             print.object)
 
-    print.object[, 1] <- format(print.object[, 1], justify = "left")
+    print.object[, 1L] <- format(print.object[, 1L], justify = "left")
 
     # Format
-    print.object[, -1] <- vapply(print.object[, -1], function(y) format(y, justify = "right"), FUN.VALUE = character(nrow(x$result) + 1))
+    print.object[, -1L] <- vapply(print.object[, -1L], function(y) format(y, justify = "right"), FUN.VALUE = character(nrow(x$result) + 1L))
 
-    print.object <- vapply(print.object, formatC, format = "f", FUN.VALUE = character(nrow(x$result) + 1))
+    print.object <- vapply(print.object, formatC, format = "f", FUN.VALUE = character(nrow(x$result) + 1L))
 
-    print.object[, 1] <- paste(" ", print.object[, 1])
+    print.object[, 1L] <- paste(" ", print.object[, 1L])
 
   #---------------------------------------
   # Within-subject design
   } else {
 
-    print.object[, !names(print.object) %in% c("var", "n", "nNA")] <- vapply(print.object[,  !names(print.object) %in% c("var", "n", "nNA")], function(y) formatC(y, format = "f", digits = digits), FUN.VALUE = character(1))
-    print.object[, names(print.object) %in% c("n", "nNA")] <- vapply(print.object[,  names(print.object) %in% c("n", "nNA")], function(y) formatC(y, format = "f", digits = 0), FUN.VALUE = character(1))
+    print.object[, !names(print.object) %in% c("var", "n", "nNA")] <- vapply(print.object[,  !names(print.object) %in% c("var", "n", "nNA")], function(y) formatC(y, format = "f", digits = digits), FUN.VALUE = character(1L))
+    print.object[, names(print.object) %in% c("n", "nNA")] <- vapply(print.object[,  names(print.object) %in% c("n", "nNA")], function(y) formatC(y, format = "f", digits = 0L), FUN.VALUE = character(1L))
 
     print.object <- rbind(c("n", "nNA", "Variable1", "M1", "SD1", "Variable2", "M2", "SD2", "M.Diff", "SD", "Estimate", "SE", "Low", "Upp"),
                           print.object)
 
-    print.object[, 1] <- format(print.object[, 1], justify = "left")
+    print.object[, 1L] <- format(print.object[, 1L], justify = "left")
 
     # Format
-    print.object[, -1] <- vapply(print.object[, -1], function(y) format(y, justify = "right"), FUN.VALUE = character(2))
+    print.object[, -1L] <- vapply(print.object[, -1L], function(y) format(y, justify = "right"), FUN.VALUE = character(2))
 
-    print.object <- vapply(print.object, formatC, format = "f", FUN.VALUE = character(2))
+    print.object <- vapply(print.object, formatC, format = "f", FUN.VALUE = character(2L))
 
-    print.object[, 1] <- paste(" ", print.object[, 1])
+    print.object[, 1L] <- paste(" ", print.object[, 1L])
 
   }
 
@@ -119,12 +119,12 @@ print.cohens.d <- function(x, digits = x$args$digits, check = TRUE, ...) {
   if(isFALSE(x$args$paired)) {
 
     # Cohens d
-    cat(paste0(" Cohen's d for bewteen-subject design with ", round(x$args$conf.level * 100), "% confidence interval\n\n"))
+    cat(paste0(" Cohen's d for bewteen-subject design with ", round(x$args$conf.level * 100L), "% confidence interval\n\n"))
 
   } else {
 
     # Cohens d
-    cat(paste0(" Cohen's d for within-subject design with ", round(x$args$conf.level * 100), "% confidence interval\n\n"))
+    cat(paste0(" Cohen's d for within-subject design with ", round(x$args$conf.level * 100L), "% confidence interval\n\n"))
 
   }
 
