@@ -22,7 +22,7 @@
 #' @examples
 #' dat <- data.frame(x = c(1, NA, NA, 6, 3),
 #'                   y = c(7, NA, 8, 9, NA),
-#'                   z = c(2, NA, 3, NA, 5))
+#'                   z = c(2, NA, 3, NA, 5), stringsAsFactors = FALSE)
 #'
 #' # Compute a summary of missing data patterns
 #' dat.pattern <- na.pattern(dat, output = FALSE)
@@ -37,14 +37,14 @@ print.na.pattern <- function(x, order = x$args$order, digits = x$args$digits, ch
   if (isTRUE(check)) {
 
     # Check order argument
-    if (isFALSE(isTRUE(order) | isFALSE(order))) {
+    if (isFALSE(isTRUE(order) || isFALSE(order))) {
 
       stop("Please specify TRUE or FALSE for the argument 'order'.", call. = FALSE)
 
     }
 
     # Check digits argument
-    if (digits %% 1 != 0 | digits < 0) {
+    if (digits %% 1L != 0L || digits < 0L) {
 
       stop("Please specify a positive integer value for the argument 'digits'", call. = FALSE)
 
@@ -68,14 +68,14 @@ print.na.pattern <- function(x, order = x$args$order, digits = x$args$digits, ch
   print.object[nrow(print.object), ncol(print.object)] <- ""
 
   # Format
-  colnames(print.object)[1] <- " Pattern"
+  colnames(print.object)[1L] <- " Pattern"
 
   ####################################################################################
   # Output
 
   cat(" Missing Data Pattern\n\n")
 
-  print(print.object, row.names = FALSE, max = 99999, right = TRUE)
+  print(print.object, row.names = FALSE, max = 99999L, right = TRUE)
 
 }
 
